==> Products.TinyMCE-1.1rc12.zip: Products.TinyMCE-1.1rc12/Products/TinyMCE/skins/tinymce/plugins/media/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.media_dlg',{
title:"\u63D2\u5165/\u7F16\u8F91\u5D4C\u5165\u5A92\u4F53",
general:"\u4E00\u822C",
advanced:"\u9AD8\u7EA7",
file:"\u6587\u4EF6/\u7F51\u5740",
list:"\u5217\u8868",
size:"\u5C3A\u5BF8",
preview:"\u9884\u89C8",
constrain_proportions:"\u4FDD\u6301\u6BD4\u4F8B",
type:"\u7C7B\u578B",
id:"Id",
name:"\u540D\u79F0",
class_name:"\u7C7B\u578B",
vspace:"\u6C34\u51C6\u95F4\u8DDD",
hspace:"\u5782\u76F4\u95F4\u8DDD",
play:"\u81EA\u52A8\u64AD\u653E",
loop:"\u56DE\u5708\u64AD\u653E",
menu:"\u663E\u793A\u529F\u80FD\u8868",
quality:"\u54C1\u8D28",
scale:"\u6BD4\u4F8B",
align:"\u5BF9\u9F50",
salign:"SAlign",
wmode:"\u89C6\u7A97\u6A21\u5F0F",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u5E95",
flashvars:"\u53C2\u6570",
liveconnect:"SWLiveConnect",
autohref:"\u81EA\u52A8HREF",
cache:"\u7F13\u5B58",
hidden:"\u9690\u85CF",
controller:"\u63A7\u5236\u53F0",
kioskmode:"Kiosk\u6A21\u5F0F",
playeveryframe:"\u64AD\u653E\u6BCF\u4E00\u5E27",
targetcache:"\u76EE\u6807\u7F13\u5B58",
correction:"\u6CA1\u6709\u4FEE\u6B63",
enablejavascript:"\u542F\u7528JavaScript",
starttime:"\u5F00\u59CB\u65F6\u95F4",
endtime:"\u7ED3\u675F\u65F6\u95F4",
href:"\u8FDE\u7ED3",
qtsrcchokespeed:"Choke speed",
target:"\u76EE\u6807",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52A8\u5F00\u59CB",
enabled:"\u542F\u7528",
fullscreen:"\u5168\u5C4F",
invokeurls:"\u76F8\u5173URLs",
mute:"\u9759\u97F3",
stretchtofit:"\u62C9\u4F38",
windowlessvideo:"\u65E0\u8FB9\u6846",
balance:"\u5E73\u8861",
baseurl:"\u57FA\u51C6URL",
captioningid:"Captioning id",
currentmarker:"\u5F53\u524D\u6807\u8BB0",
currentposition:"\u5F53\u524D\u4F4D\u7F6E",
defaultframe:"\u9ED8\u8BA4\u5E27",
playcount:"\u64AD\u653E\u8BA1\u6570",
rate:"\u5E27\u7387",
uimode:"\u9762\u677F\u6A21\u5F0F",
flash_options:"Flash\u9009\u9879",
qt_options:"Quicktime\u9009\u9879",
wmp_options:"Windows media player\u9009\u9879",
rmp_options:"Real media player\u9009\u9879",
shockwave_options:"Shockwave\u9009\u9879",
autogotourl:"\u81EA\u52A8\u8F6C\u5230URL",
center:"\u4E2D\u5FC3",
imagestatus:"\u56FE\u50CF\u72B6\u6001",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"\u9884\u8BFB\u53D6",
shuffle:"Shuffle",
console:"\u63A7\u5236\u53F0",
numloop:"\u56DE\u5708\u6B21\u6570",
controls:"\u63A7\u5236\u5668",
scriptcallbacks:"\u811A\u672C\u56DE\u6863",
swstretchstyle:"\u62C9\u5347\u6A21\u5F0F",
swstretchhalign:"\u6C34\u51C6\u62C9\u5347",
swstretchvalign:"\u5782\u76F4\u62C9\u5347",
sound:"\u58F0\u97F3",
progress:"\u8FDB\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"\u6D41\u5F0Frtsp\u8D44\u6E90\u5E94\u8BE5\u6DFB\u52A0\u5230\u201C\u9AD8\u7EA7\u201D\u4E2DQT Src\u3002\n\u540C\u65F6\u6DFB\u52A0\u975E\u6D41\u5F0F\u8D44\u6E90\u5230Src\u3002",
align_top:"\u4E0A\u65B9",
align_right:"\u9760\u53F3",
align_bottom:"\u4E0B\u65B9",
align_left:"\u9760\u5DE6",
align_center:"\u4E2D\u95F4",
align_top_left:"\u5DE6\u4E0A",
align_top_right:"\u53F3\u4E0A",
align_bottom_left:"\u5DE6\u4E0B",
align_bottom_right:"\u53F3\u4E0B",
flv_options:"Flash\u89C6\u9891\u9009\u9879",
flv_scalemode:"Scale mode",
flv_buffer:"\u7F13\u51B2",
flv_startimage:"\u5F00\u59CB\u753B\u9762",
flv_starttime:"\u5F00\u59CB\u65F6\u95F4",
flv_defaultvolume:"\u9884\u8BBE\u97F3\u91CF",
flv_hiddengui:"\u9690\u85CFGUI",
flv_autostart:"\u81EA\u52A8\u64AD\u653E",
flv_loop:"\u56DE\u5708",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"\u5E73\u6ED1\u56FE\u50CF",
flv_jscallback:"JS\u56DE\u6863"
});

==> Products.TinyMCE-1.2.12.zip: Products.TinyMCE-1.2.12/Products/TinyMCE/skins/tinymce/plugins/media/langs/ch_dlg.js <==
tinyMCE.addI18n('ch.media_dlg',{
title:"\u63D2\u5165/\u7F16\u8F91\u5D4C\u5165\u5A92\u4F53",
general:"\u4E00\u822C",
advanced:"\u9AD8\u7EA7",
file:"\u6587\u4EF6/\u7F51\u5740",
list:"\u5217\u8868",
size:"\u5C3A\u5BF8",
preview:"\u9884\u89C8",
constrain_proportions:"\u4FDD\u6301\u6BD4\u4F8B",
type:"\u7C7B\u578B",
id:"Id",
name:"\u540D\u79F0",
class_name:"\u7C7B\u578B",
vspace:"\u6C34\u51C6\u95F4\u8DDD",
hspace:"\u5782\u76F4\u95F4\u8DDD",
play:"\u81EA\u52A8\u64AD\u653E",
loop:"\u5FAA\u73AF\u64AD\u653E",
menu:"\u663E\u793A\u83DC\u5355",
quality:"\u54C1\u8D28",
scale:"\u6BD4\u4F8B",
align:"\u5BF9\u9F50",
salign:"SAlign",
wmode:"\u7A97\u53E3\u6A21\u5F0F",
bgcolor:"\u80CC\u666F\u8272",
base:"\u57FA\u5E95",
flashvars:"\u53C2\u6570",
liveconnect:"SWLiveConnect",
autohref:"\u81EA\u52A8HREF",
cache:"\u7F13\u5B58",
hidden:"\u9690\u85CF",
controller:"\u63A7\u5236\u53F0",
kioskmode:"Kiosk\u6A21\u5F0F",
playeveryframe:"\u64AD\u653E\u6BCF\u4E00\u5E27",
targetcache:"\u76EE\u6807\u7F13\u5B58",
correction:"\u6CA1\u6709\u4FEE\u6B63",
enablejavascript:"\u542F\u7528JavaScript",
starttime:"\u5F00\u59CB\u65F6\u95F4",
endtime:"\u7ED3\u675F\u65F6\u95F4",
href:"\u94FE\u63A5",
qtsrcchokespeed:"Choke speed",
target:"\u76EE\u6807",
volume:"\u97F3\u91CF",
autostart:"\u81EA\u52A8\u5F00\u59CB",
enabled:"\u542F\u7528",
fullscreen:"\u5168\u5C4F",
invokeurls:"\u76F8\u5173URLs",
mute:"\u9759\u97F3",
stretchtofit:"\u62C9\u4F38",
windowlessvideo:"\u65E0\u8FB9\u6846",
balance:"\u5E73\u8861",
baseurl:"\u57FA\u51C6URL",
captioningid:"Captioning id",
currentmarker:"\u5F53\u524D\u6807\u8BB0",
currentposition:"\u5F53\u524D\u4F4D\u7F6E",
defaultframe:"\u9ED8\u8BA4\u5E27",
playcount:"\u64AD\u653E\u8BA1\u6570",
rate:"\u5E27\u7387",
uimode:"\u9762\u677F\u6A21\u5F0F",
flash_options:"Flash\u9009\u9879",
qt_options:"Quicktime\u9009\u9879",
wmp_options:"Windows media player\u9009\u9879",
rmp_options:"Real media player\u9009\u9879",
shockwave_options:"Shockwave\u9009\u9879",
autogotourl:"\u81EA\u52A8\u8F6C\u5230URL",
center:"\u4E2D\u5FC3",
imagestatus:"\u56FE\u50CF\u72B6\u6001",
maintainaspect:"Maintain aspect",
nojava:"No java",
prefetch:"\u9884\u8BFB\u53D6",
shuffle:"Shuffle",
console:"\u63A7\u5236\u53F0",
numloop:"\u5FAA\u73AF\u6B21\u6570",
controls:"\u63A7\u5236\u5668",
scriptcallbacks:"\u811A\u672C\u8C03\u7528",
swstretchstyle:"\u62C9\u5347\u6A21\u5F0F",
swstretchhalign:"\u6C34\u51C6\u62C9\u5347",
swstretchvalign:"\u5782\u76F4\u62C9\u5347",
sound:"\u58F0\u97F3",
progress:"\u8FDB\u5EA6",
qtsrc:"QT Src",
qt_stream_warn:"\u6D41\u5F0Frtsp\u8D44\u6E90\u5E94\u8BE5\u6DFB\u52A0\u5230\u201C\u9AD8\u7EA7\u201D\u4E2DQT Src\u3002\n\u540C\u65F6\u6DFB\u52A0\u975E\u6D41\u5F0F\u8D44\u6E90\u5230Src\u3002",
align_top:"\u4E0A\u65B9",
align_right:"\u9760\u53F3",
align_bottom:"\u4E0B\u65B9",
align_left:"\u9760\u5DE6",
align_center:"\u4E2D\u95F4",
align_top_left:"\u5DE6\u4E0A",
align_top_right:"\u53F3\u4E0A",
align_bottom_left:"\u5DE6\u4E0B",
align_bottom_right:"\u53F3\u4E0B",
flv_options:"Flash\u89C6\u9891\u9009\u9879",
flv_scalemode:"Scale mode",
flv_buffer:"\u7F13\u51B2",
flv_startimage:"\u5F00\u59CB\u753B\u9762",
flv_starttime:"\u5F00\u59CB\u65F6\u95F4",
flv_defaultvolume:"\u9884\u8BBE\u97F3\u91CF",
flv_hiddengui:"\u9690\u85CFGUI",
flv_autostart:"\u81EA\u52A8\u64AD\u653E",
flv_loop:"\u5FAA\u73AF",
flv_showscalemodes:"Show scale modes",
flv_smoothvideo:"\u5E73\u6ED1\u56FE\u50CF",
flv_jscallback:"JS\u8C03\u7528"
});
